@@ -1,7 +1,7 @@
 use crate::error::Error::ImgurError;
 use crate::request_builders::{
-    DeleteImage, FavoriteImage, GenerateAccessToken, GetAccount, GetImage, ListAccountImages,
-    UpdateImage, UploadImage,
+    DeleteImage, FavoriteImage, GenerateAccessToken, GetAccount, GetAccountImage,
+    GetAccountImagesCount, GetImage, ListAccountImages, UpdateImage, UploadImage,
 };
 use crate::result::Result;
 use serde::de::DeserializeOwned;
@@ -39,6 +39,18 @@ impl Client {
         GetAccount::new(self, user_name.into())
     }
 
+    pub fn get_account_image(
+        &self,
+        user_name: impl Into<String>,
+        image_id: impl Into<String>,
+    ) -> GetAccountImage {
+        GetAccountImage::new(self, user_name.into(), image_id.into())
+    }
+
+    pub fn get_account_images_count(&self, user_name: impl Into<String>) -> GetAccountImagesCount {
+        GetAccountImagesCount::new(self, user_name.into())
+    }
+
     pub fn get_image(&self, image_hash: impl Into<String>) -> GetImage {
         GetImage::new(self, image_hash.into())
     }
