@@ -12,8 +12,9 @@ pub async fn delete_image(opt: Opt) -> Result<()> {
         let client = Client::builder()
             .credentials(access_token, client_id)
             .build()?;
-        let basic = client.delete_image(hash).send().await?;
-        dbg!(basic);
+        let model = client.delete_image(hash).send().await?;
+        let json = serde_json::to_string(&model)?;
+        println!("{}", json);
         Ok(())
     } else {
         panic!()
